@@ -2,11 +2,17 @@
 from django.contrib import admin
 from django import forms
 from easy_news.models import News
+from easy_news import settings as news_settings
+if news_settings.NEWS_TAGGING:
+    from tagging.forms import TagField
 
 class NewsForm(forms.ModelForm):
     class Meta:
         model = News
     title = forms.CharField(widget=forms.Textarea(attrs={'rows': 3}), max_length=500)
+    if news_settings.NEWS_TAGGING:
+        tags = TagField(required=False)
+
 
 class NewsAdmin(admin.ModelAdmin):
     list_display = ['title', 'date', 'show', ]
